﻿// --------------------------------------------------------------------------------------------------------------------
// <copyright file="AudioDefaultsView.xaml.cs" company="HandBrake Project (http://handbrake.fr)">
//   This file is part of the HandBrake source code - It may be used under the terms of the GNU General Public License.
// </copyright>
// <summary>
//   Interaction logic for AudioDefaultsView.xaml
// </summary>
// --------------------------------------------------------------------------------------------------------------------

namespace HandBrakeWPF.Views
{
    using System.Windows;
    
    public partial class AudioDefaultsView : Window
    {
        public AudioDefaultsView()
        {
            this.InitializeComponent();
        }
    }
}
